From 80e4f9e15d02a4337287627d2b23af558def5cb7 Mon Sep 17 00:00:00 2001
From: Bharath Rupireddy <bharath.rupireddy@enterprisedb.com>
Date: Mon, 11 Jan 2021 12:48:28 +0530
Subject: [PATCH v1] Avoid Sys Cache Lookups in Error Callbacks

When in SearchCatCacheInternal, Make sure we're not in an error
callback. It's unsafe to access the system cahe or catalogue
within an error callback because the xact might have been broken.
---
 src/backend/utils/cache/catcache.c | 7 +++++++
 1 file changed, 7 insertions(+)

diff --git a/src/backend/utils/cache/catcache.c b/src/backend/utils/cache/catcache.c
index ba95755867..c58e1116ab 100644
--- a/src/backend/utils/cache/catcache.c
+++ b/src/backend/utils/cache/catcache.c
@@ -1212,6 +1212,13 @@ SearchCatCacheInternal(CatCache *cache,
 	/* Make sure we're in an xact, even if this ends up being a cache hit */
 	Assert(IsTransactionState());
 
+	/*
+	 * Make sure we're not in an error callback. It's unsafe to access the
+	 * system cahe or catalogue within an error callback because the xact might
+	 * have been broken.
+	 */
+	Assert(!error_context_stack);
+
 	Assert(cache->cc_nkeys == nkeys);
 
 	/*
-- 
2.25.1

